INTE Sites

## INTE Africa UAT Sites: Tanzania

Select a site to continue

INTE Africa UAT Sites: Tanzania
Home Bagamoyo District hospital Buguruni Health Centre Cardinal Rugambwa Hospital Consolata Sisters Dispensary Kinondoni Hospital Kisarawe District Hospital Magomeni Health Centre Mbagala Rangi Tatu Hospital Mnazi Mmoja Hospital Sinza Hospital St.Vincent Health Centre Tambuka Reli Dispensary Tandale Health Centre Tegeta Mission Centre Temeke Regional Referral Hospital Yombo Vituka Health Centre